class DBUtilsSecrets:

    def get(self, *args):
        print("calling DBUtilsSecrets.get func from dummy dbutils package, and no operation performed.")

class DBUtilsWidgets:

    def removeAll(self):
        print("calling DBUtilsWidgets.removeAll func from dummy dbutils package, and no operation performed.")

    def text(self, *args):
        print("calling DBUtilsWidgets.text func from dummy dbutils package, and no operation performed.")

    def get(self, *args):
        print("calling DBUtilsWidgets.get func from dummy dbutils package, and no operation performed.")


class DButilsFunctions:

    def ls(self, dir: str):
        print("calling DButilsFunctions.ls func from dummy dbutils package, and no operation performed.")

    def mkdirs(self, dir: str):
        print("calling DButilsFunctions.mkdirs func from dummy dbutils package, and no operation performed.")

    def mv(self, src: str, tgt: str):
        print("calling DButilsFunctions.mv func from dummy dbutils package, and no operation performed.")

class DBUtils:

    def __init__(self):
        self.fs = DButilsFunctions()
        self.widgets = DBUtilsWidgets()
        self.secrets = DBUtilsSecrets()

dbutils = DBUtils()

# dbutils.fs.ls("dir")
# dbutils.fs.mkdirs("dir")
# dbutils.fs.mv("src", "tgt")

